#[repr(u8)]pub enum Pcf {
FLTR_ALL = 0,
FW_XCPT_PAU = 1,
FW_ALL = 2,
FW_PASS = 3,
}Variants
FLTR_ALL = 0
MAC filters all control packets from reaching the application
FW_XCPT_PAU = 1
MAC forwards all control packets except Pause packets to the application even if they fail the Address filter
FW_ALL = 2
MAC forwards all control packets to the application even if they fail the Address filter
FW_PASS = 3
MAC forwards the control packets that pass the Address filter
Implementations